@@ -1,25 +1,21 @@
 # -*- coding: utf-8 -*-
-from colorama import Fore
-from colorama import Style
-from datetime import date
-from lxml import etree
-from mrbob import hooks
-from mrbob.bobexceptions import MrBobError
-from mrbob.bobexceptions import SkipQuestion
-from mrbob.bobexceptions import ValidationError
-from mrbob.rendering import jinja2_env
-from six.moves import input
-
-import case_conversion as cc
 import codecs
 import keyword
 import os
 import re
-import six
 import string
 import subprocess
 import sys
+from datetime import date
 
+import case_conversion as cc
+import six
+from colorama import Fore, Style
+from lxml import etree
+from mrbob import hooks
+from mrbob.bobexceptions import MrBobError, SkipQuestion, ValidationError
+from mrbob.rendering import jinja2_env
+from six.moves import input
 
 try:
     from ConfigParser import ConfigParser
@@ -33,6 +29,16 @@ ZCML_NAMESPACES = {
 }
 
 
+CONTENT_TYPE_INTERFACES = {
+    "*": "*",
+    "Document": "plone.app.contenttypes.interfaces.IDocument",
+    "Folder": "plone.app.contenttypes.interfaces.IFolder",
+    "Collection": "plone.app.contenttypes.interfaces.ICollection",
+    "Event": "plone.app.contenttypes.interfaces.IEvent",
+    "News Items": "plone.app.contenttypes.interfaces.INewsItem",
+}
+
+
 def to_boolean(value):
     if not value:
         return False
@@ -49,10 +55,10 @@ jinja2_env.filters["to_boolean"] = to_boolean
 
 
 def git_support_enabled(configurator, question):
-    disabled = configurator.variables.get("package.git.disabled", u"False")
+    disabled = configurator.variables.get("package.git.disabled", "False")
     if hooks.to_boolean(None, None, disabled):
-        echo(u"GIT support disabled!!!")
-        raise SkipQuestion(u"GIT support is disabled, skip question!")
+        echo("GIT support disabled!!!")
+        raise SkipQuestion("GIT support is disabled, skip question!")
 
 
 def echo(msg, msg_type=None):
@@ -79,7 +85,7 @@ class BobConfig(object):
 def git_support(configurator):
     """check if GIT support is disabled/enabled"""
     git_support = True
-    disabled = configurator.variables.get("package.git.disabled", u"False")
+    disabled = configurator.variables.get("package.git.disabled", "False")
     if hooks.to_boolean(None, None, disabled):
         echo("GIT support disabled!")
         git_support = False
@@ -89,12 +95,12 @@ def git_support(configurator):
 def git_init(configurator):
     if not git_support(configurator):
         return
-    git_init_flag = configurator.variables.get("package.git.init", u"False")
+    git_init_flag = configurator.variables.get("package.git.init", "False")
     if not hooks.to_boolean(None, None, str(git_init_flag)):
         echo("git init is disabled!")
         return
     params = ["git", "init"]
-    echo(u"RUN: {0}".format(" ".join(params)), "info")
+    echo("RUN: {0}".format(" ".join(params)), "info")
     try:
         result = subprocess.check_output(params, cwd=configurator.target_directory)
     except subprocess.CalledProcessError as e:
@@ -114,15 +120,15 @@ def git_commit(configurator, msg):
         or configurator.target_directory
     )
     params1 = ["git", "add", "."]
-    params2 = ["git", "commit", "-m", u'"{0}"'.format(msg)]
+    params2 = ["git", "commit", "-m", '"{0}"'.format(msg)]
     git_autocommit = None
     run_git_commit = True
-    autocommit_flag = configurator.variables.get("package.git.autocommit", u"False")
+    autocommit_flag = configurator.variables.get("package.git.autocommit", "False")
     if hooks.to_boolean(None, None, autocommit_flag):
         git_autocommit = True
     if not non_interactive and not git_autocommit:
         echo(
-            u"Should we run?:\n{0}\n{1}\nin: {2}".format(
+            "Should we run?:\n{0}\n{1}\nin: {2}".format(
                 " ".join(params1), " ".join(params2), working_dir
             ),
             "info",
@@ -133,7 +139,7 @@ def git_commit(configurator, msg):
         echo("Skip git commit!", "warning")
         return
 
-    echo(u"RUN: {0}".format(" ".join(params1)), "info")
+    echo("RUN: {0}".format(" ".join(params1)), "info")
     try:
         result1 = subprocess.check_output(params1, cwd=working_dir)
     except subprocess.CalledProcessError as e:
@@ -142,7 +148,7 @@ def git_commit(configurator, msg):
         if result1:
             echo(result1, "info")
 
-    echo(u"RUN: {0}".format(" ".join(params2)), "info")
+    echo("RUN: {0}".format(" ".join(params2)), "info")
     try:
         result2 = subprocess.check_output(params2, cwd=working_dir)
     except subprocess.CalledProcessError as e:
@@ -155,7 +161,7 @@ def git_clean_state_check(configurator, question):
     if not git_support(configurator):
         return
     params = ["git", "status", "--porcelain", "--ignore-submodules"]
-    echo(u"\nRUN: {0}".format(" ".join(params)), "info")
+    echo("\nRUN: {0}".format(" ".join(params)), "info")
     try:
         result = subprocess.check_output(params, cwd=configurator.target_directory)
     except subprocess.CalledProcessError as e:
@@ -165,7 +171,7 @@ def git_clean_state_check(configurator, question):
             echo("Git state is clean.\n", "info")
             raise SkipQuestion("Git state is clean, so we skip this question.")
         echo(
-            u"git status result:\n----------------------------\n{0}".format(result),
+            "git status result:\n----------------------------\n{0}".format(result),
             "warning",
         )
 
@@ -173,11 +179,11 @@ def git_clean_state_check(configurator, question):
 def check_klass_name(configurator, question, answer):
     if keyword.iskeyword(answer):
         raise ValidationError(
-            u"{key} is a reserved Python keyword".format(key=answer)
+            "{key} is a reserved Python keyword".format(key=answer)
         )  # NOQA: E501
     if not re.match("[a-zA-Z_][a-zA-Z0-9_]*$", answer):
         raise ValidationError(
-            u"{key} is not a valid class identifier".format(key=answer)
+            "{key} is not a valid class identifier".format(key=answer)
         )  # NOQA: E501
     return answer
 
@@ -185,11 +191,11 @@ def check_klass_name(configurator, question, answer):
 def check_method_name(configurator, question, answer):
     if keyword.iskeyword(answer):
         raise ValidationError(
-            u"{key} is a reserved Python keyword".format(key=answer)
+            "{key} is a reserved Python keyword".format(key=answer)
         )  # NOQA: E501
-    if not re.match("[a-z_][a-z0-9_]*$", answer):
+    if not re.match("[a-zA-Z_][a-zA-Z0-9_]*$", answer):
         raise ValidationError(
-            u"{key} is not a valid method identifier".format(key=answer)
+            "{key} is not a valid method identifier".format(key=answer)
         )  # NOQA: E501
     return answer
 
@@ -264,15 +270,11 @@ def validate_packagename(configurator):
     if package_dir.startswith(".") or package_dir.endswith("."):
         fail = True
 
-    parts = len(package_dir.split("."))
-    if parts < 2 or parts > 3:
-        fail = True
-
     if fail:
         msg = (
-            u"Error: '{0}' is not a valid packagename.\n"
+            "Error: '{0}' is not a valid packagename.\n"
             "Please use a valid name (like collective.myaddon or "
-            u"plone.app.myaddon)".format(package_dir)
+            "plone.app.myaddon)".format(package_dir)
         )
         sys.exit(msg)
 
@@ -372,7 +374,7 @@ def update_file(configurator, file_path, match_str, insert_str):
     if not changed:
         print(
             "WARNING: We couldn't find the match_str, "  # NOQA
-            u"skip inserting into {0}:\n".format(file_path)  # NOQA
+            "skip inserting into {0}:\n".format(file_path)  # NOQA
         )
 
 
@@ -422,7 +424,7 @@ def base_prepare_renderer(configurator):
         configurator
     )
     if not configurator.variables["package.root_folder"]:
-        raise MrBobError(u"No setup.py found in path!\n")
+        raise MrBobError("No setup.py found in path!\n")
     configurator.variables["package.dottedname"] = configurator.variables[
         "package.root_folder"
     ].split("/")[-1]
@@ -438,12 +440,23 @@ def base_prepare_renderer(configurator):
     )
 
     package_subpath = dottedname_to_path(configurator.variables["package.dottedname"])
-    configurator.variables["package_folder_rel_path"] = u"/src/" + package_subpath
+    configurator.variables["package_folder_rel_path"] = "/src/" + package_subpath
     configurator.variables["package_folder"] = (
         configurator.variables["package.root_folder"]
         + configurator.variables["package_folder_rel_path"]
     )
     configurator.target_directory = configurator.variables["package.root_folder"]
+    camelcasename = (
+        configurator.variables["package.dottedname"]
+        .replace(".", " ")
+        .title()
+        .replace(" ", "")
+        .replace("_", "")
+    )
+    browserlayer = "{0}Layer".format(camelcasename)
+
+    # package.browserlayer = 'CollectiveFooSomethingLayer'
+    configurator.variables["package.browserlayer"] = browserlayer
     set_global_vars(configurator)
     return configurator
 
@@ -489,3 +502,12 @@ def get_normalized_classname(name):
 def get_normalized_ftiname(name):
     normalized_name = name.replace(" ", "_")
     return normalized_name
+
+
+def get_normalized_themename(name):
+    name = name.replace("(", "")
+    name = name.replace(")", "")
+    name = name.replace("-", "")
+    name = name.replace(" ", "_")
+    normalized_name = cc.dashcase(name)
+    return normalized_name
