@@ -24,16 +24,6 @@ def plone_buildout():
     return reg
 
 
-def plone_theme_package():
-    reg = RegEntry()
-    reg.template = "bobtemplates.plone:theme_package"
-    reg.plonecli_alias = "theme_package"
-    reg.deprecated = True
-    reg.info = """Please use the theme_barceloneta subtemplate!
-    """
-    return reg
-
-
 def plone_theme():
     reg = RegEntry()
     reg.template = "bobtemplates.plone:theme"
@@ -50,6 +40,14 @@ def plone_theme_barceloneta():
     return reg
 
 
+def plone_theme_basic():
+    reg = RegEntry()
+    reg.template = "bobtemplates.plone:theme_basic"
+    reg.plonecli_alias = "theme_basic"
+    reg.depend_on = "plone_addon"
+    return reg
+
+
 def plone_content_type():
     reg = RegEntry()
     reg.template = "bobtemplates.plone:content_type"
@@ -136,3 +134,19 @@ def plone_upgrade_step():
     reg.plonecli_alias = "upgrade_step"
     reg.depend_on = "plone_addon"
     return reg
+
+
+def plone_controlpanel():
+    reg = RegEntry()
+    reg.template = "bobtemplates.plone:controlpanel"
+    reg.plonecli_alias = "controlpanel"
+    reg.depend_on = "plone_addon"
+    return reg
+
+
+def plone_mockup_pattern():
+    reg = RegEntry()
+    reg.template = "bobtemplates.plone:mockup_pattern"
+    reg.plonecli_alias = "mockup_pattern"
+    reg.depend_on = "plone_addon"
+    return reg
