@@ -1,19 +1,21 @@
 # -*- coding: utf-8 -*-
 
-from bobtemplates.plone.base import base_prepare_renderer
-from bobtemplates.plone.base import git_commit
-from bobtemplates.plone.base import remove_unwanted_files
-from bobtemplates.plone.base import update_configure_zcml
-from bobtemplates.plone.utils import run_isort
-
 import case_conversion as cc
 
+from bobtemplates.plone.base import (
+    base_prepare_renderer,
+    git_commit,
+    remove_unwanted_files,
+    update_configure_zcml,
+)
+from bobtemplates.plone.utils import run_black, run_isort
+
 
 def _update_package_configure_zcml(configurator):
     path = "{0}".format(
         configurator.variables["package_folder"],
     )
-    file_name = u"configure.zcml"
+    file_name = "configure.zcml"
     match_xpath = "zope:include[@package='.indexers']"
     match_str = "-*- extra stuff goes here -*-"
     insert_str = """
@@ -33,7 +35,7 @@ def _update_indexers_configure_zcml(configurator):
     path = "{0}/indexers".format(
         configurator.variables["package_folder"],
     )
-    file_name = u"configure.zcml"
+    file_name = "configure.zcml"
     example_file_name = "{0}.example".format(file_name)
     match_xpath = "zope:include[@package='.{0}']".format(
         configurator.variables["indexer_name"]
@@ -83,6 +85,7 @@ def post_renderer(configurator):
     _update_indexers_configure_zcml(configurator)
     _remove_unwanted_files(configurator)
     run_isort(configurator)
+    run_black(configurator)
     git_commit(
         configurator,
         "Add indexer: {0}".format(
