@@ -1,16 +1,19 @@
 # -*- coding: utf-8 -*-
 """Generate view."""
 
-from bobtemplates.plone.base import base_prepare_renderer
-from bobtemplates.plone.base import git_commit
-from bobtemplates.plone.base import update_file
-from bobtemplates.plone.base import ZCML_NAMESPACES
-from bobtemplates.plone.utils import run_isort
+import os
+
+import case_conversion as cc
 from lxml import etree
 from mrbob.bobexceptions import SkipQuestion
 
-import case_conversion as cc
-import os
+from bobtemplates.plone.base import (
+    ZCML_NAMESPACES,
+    base_prepare_renderer,
+    git_commit,
+    update_file,
+)
+from bobtemplates.plone.utils import run_black, run_isort
 
 
 def get_view_name_from_python_class(configurator, question):
@@ -23,12 +26,12 @@ def get_view_name_from_python_class(configurator, question):
 def check_viewlet_template_answer(configurator, question):
     if not configurator.variables["viewlet_template"]:
         raise SkipQuestion(
-            u"No view template, so we skip view template name question."
+            "No view template, so we skip view template name question."
         )  # NOQA: E501
 
 
 def _update_configure_zcml(configurator):
-    file_name = u"configure.zcml"
+    file_name = "configure.zcml"
     file_path = configurator.variables["package_folder"] + "/" + file_name
     namespaces = "{http://namespaces.zope.org/zope}"
 
@@ -51,7 +54,7 @@ def _update_configure_zcml(configurator):
 
 
 def _update_viewlets_configure_zcml(configurator):
-    file_name = u"configure.zcml"
+    file_name = "configure.zcml"
     directory_path = configurator.variables["package_folder"] + "/viewlets/"
     file_path = directory_path + file_name
 
@@ -79,11 +82,7 @@ def _update_viewlets_configure_zcml(configurator):
 
     match_str = "-*- extra stuff goes here -*-"
 
-    if configurator.variables["plone.is_plone5"]:
-        iface_name = "plone.app.contenttypes.interfaces.IDocument"
-    else:
-        # BBB Plone 4 fallback:
-        iface_name = "Products.ATContentTypes.interfaces.document.IATDocument"
+    iface_name = "plone.app.contenttypes.interfaces.IDocument"
 
     if configurator.variables["viewlet_template"]:
         insert_str = """
@@ -131,13 +130,13 @@ def _update_viewlets_configure_zcml(configurator):
 def _delete_unwanted_files(configurator):
     directory_path = configurator.variables["package_folder"] + "/viewlets/"
     if not configurator.variables["viewlet_template"]:
-        template_file_name = u"{0}.pt".format(
+        template_file_name = "{0}.pt".format(
             configurator.variables["viewlet_template_name"],
         )
         file_path = directory_path + template_file_name
         os.remove(file_path)
 
-    file_name = u"configure.zcml.example"
+    file_name = "configure.zcml.example"
     file_list = os.listdir(os.path.dirname(directory_path))
     if file_name in file_list:
         file_path = directory_path + file_name
@@ -179,6 +178,7 @@ def post_renderer(configurator):
     _update_viewlets_configure_zcml(configurator)
     _delete_unwanted_files(configurator)
     run_isort(configurator)
+    run_black(configurator)
     git_commit(
         configurator,
         "Add viewlet: {0}".format(
